Exception: Capsium::Package::Cipher::CipherError
- Defined in:
- lib/capsium/package/cipher.rb,
sig/capsium/package/cipher.rbs
Overview
Structural problems: unreadable input, missing zip entries, unsupported envelope algorithms, unloadable keys.
Structural problems: unreadable input, missing zip entries, unsupported envelope algorithms, unloadable keys.